package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import java.io.IOException;
import java.util.Enumeration;

public class PrivateKeyInfo extends ASN1Encodable {
   private DERObject privKey;
   private AlgorithmIdentifier algId;
   private ASN1Set attributes;

   public static PrivateKeyInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static PrivateKeyInfo getInstance(Object obj) {
      if (obj instanceof PrivateKeyInfo) {
         return (PrivateKeyInfo)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new PrivateKeyInfo((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public PrivateKeyInfo(AlgorithmIdentifier algId, DERObject privateKey) {
      this(algId, privateKey, (ASN1Set)null);
   }

   public PrivateKeyInfo(AlgorithmIdentifier algId, DERObject privateKey, ASN1Set attributes) {
      this.privKey = privateKey;
      this.algId = algId;
      this.attributes = attributes;
   }

   public PrivateKeyInfo(ASN1Sequence seq) {
      Enumeration seq1;
      if (((DERInteger)(seq1 = seq.getObjects()).nextElement()).getValue().intValue() == 0) {
         PrivateKeyInfo var10001 = this;
         this.algId = new AlgorithmIdentifier((ASN1Sequence)seq1.nextElement());

         try {
            var10001.privKey = (new ASN1InputStream(((ASN1OctetString)seq1.nextElement()).getOctets())).readObject();
         } catch (IOException var2) {
            throw new IllegalArgumentException("Error recoverying private key from sequence");
         }

         if (seq1.hasMoreElements()) {
            this.attributes = ASN1Set.getInstance((ASN1TaggedObject)seq1.nextElement(), false);
         }

      } else {
         throw new IllegalArgumentException("wrong version for private key info");
      }
   }

   public AlgorithmIdentifier getAlgorithmId() {
      return this.algId;
   }

   public DERObject getPrivateKey() {
      return this.privKey;
   }

   public ASN1Set getAttributes() {
      return this.attributes;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(new DERInteger(0));
      var10001.add(this.algId);
      var10001.add(new DEROctetString(this.privKey));
      ASN1Set var3;
      if ((var3 = this.attributes) != null) {
         DERTaggedObject var2;
         var2 = new DERTaggedObject.<init>(false, 0, var3);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
